@@ -2,10 +2,11 @@
 /*
  * This file is part of PharIo\Manifest.
  *
- * (c) Arne Blankerts <arne@blankerts.de>, Sebastian Heuer <sebastian@phpeople.de>, Sebastian Bergmann <sebastian@phpunit.de>
+ * Copyright (c) Arne Blankerts <arne@blankerts.de>, Sebastian Heuer <sebastian@phpeople.de>, Sebastian Bergmann <sebastian@phpunit.de> and contributors
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
+ *
  */
 namespace PharIo\Manifest;
 
@@ -40,4 +41,22 @@ class AuthorTest extends TestCase {
     public function testCanBeUsedAsString(): void {
         $this->assertEquals('Joe Developer <user@example.com>', $this->author->asString());
     }
+
+    public function testCanBeCreatedWithoutEmail(): void {
+        $this->assertInstanceOf(Author::class, new Author('Joe Developer'));
+    }
+
+    public function testHasEmailReturnsTrueWhenEMailIsSet(): void {
+        $this->assertTrue($this->author->hasEmail());
+    }
+
+    public function testHasEmailReturnsFalseOnMissingEMail(): void {
+        $this->assertFalse((new Author('Joe Developer'))->hasEmail());
+    }
+
+    public function testThrowsExceptionWhenMissingEmailAddressIsQueried(): void {
+        $author = new Author('Joe Developer');
+        $this->expectException(NoEmailAddressException::class);
+        $author->getEmail();
+    }
 }
